// AUTO-GENERATED BY UpdateGenVersion.bat 6761887da2286669652a8869f02d862c3e2243a5
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "6761887da2286669652a8869f02d862c3e2243a5";
